In this project, we gather reproduction attempts from the Challenger
study. In particular, we try to reperform some of the analysis provided
in *Risk Analysis of the Space Shuttle: Pre-Challenger Prediction of
Failure* by *Siddhartha R. Dalal, Edward B. Fowlkes, Bruce Hoadley*
published in *Journal of the American Statistical Association*, Vol. 84,
No. 408 (Dec., 1989), pp. 945-957 and available at
[here](https://studies2.hec.fr/jahia/webdav/site/hec/shared/sites/czellarv/acces_anonyme/OringJASA_1989.pdf)
(here is [the official JASA
webpage](http://www.jstor.org/stable/2290069)).

On the fourth page of this article, they indicate that the maximum
likelihood estimates of the logistic regression using only temperature
are: $`\hat{\alpha}=5.085`$ and $`\hat{\beta}=-0.1156`$ and their
asymptotic standard errors are $`s_{\hat{\alpha}}=3.052`$ and
$`s_{\hat{\beta}}=0.047`$. The Goodness of fit indicated for this model
was $`G^{2} = 18.086`$ with 21 degrees of freedom. Our goal is to
reproduce the computation behind these values and the Figure 4 of this
article, possibly in a nicer looking way.


[*Here is our successful replication of Dalal et al. results using
R*](challenger.pdf).

1.  Try to **replicate the computation** from Dalal et al. In case it
    helps, we provide you with twoimplementations of this case study
    but we encourage you to **reimplement them by yourself** using both
    your favourite language and an other language you do not know yet.
    -   A [Jupyter Python3 notebook](src/Python3/challenger.ipynb)
    -   An [Rmarkdown document](src/R/challenger.Rmd)
2.  Then **update the following table with your own results by
    indicating in each column:**
	-   Language: R, Python3, Julia, Perl, C...
	-   Language version:
	-   Main libraries: please indicate the versions of all the loaded
		libraries
    -   Tool: Jupyter, Rstudio, Emacs
	-   Operating System: Linux, Mac OS X, Windows, Android, ... along with
      its version
	-   $`\hat{\alpha}`$ and $`\hat{\beta}`$: Identical, Similar, Different,
Non functional (expected values are $`5.085`$ and $`-0.1156`$)
	-   $`s_{\hat{\alpha}}`$ and $`s_{\hat{\beta}}`$: Identical, Similar,
			Different, Non functional (expected values are $`3.052`$ and $`0.047`$)
	-   $`G^2`$ and degree of freedom: Identical, Similar, Different, Non
		functional (expected values are $`18.086`$ and $`21`$).
	-   Figure: Similar, Different, Non functional, Did not succeed
	-   Confidence region: Identical (to [the one obtained with R](challenger.pdf)), Similar, Quite Different, Did not succeed
 
| Language | Language version | Main libraries                                                | Tool    | Operating System               | $`\hat{\alpha}= 5.085`$ $`\hat{\beta} = -0.1156`$ | $`s_{\hat{\alpha}} = 3.052`$ $`s_{\hat{\beta}} = 0.047`$ | $`G^{2} = 18.086`$ $`dof = 21`$ | Figure    | Confidence Region | Link to the document                                                                                                                                                                                                                                                                                                         | Author      |
| -------- | ---------------- | ------------------------------------------------------------- | ------- | ----------------------------   | -------------                            | ----------                                | ----------                   | --------- | ----------   | -----------------------------------------------------------------                                                                                                                                                                                                                                                                                            | ----------- |
| R        |            3.5.1 | ggplot2 3.0.0                                                 | RStudio | Debian GNU/Linux buster/sid    | Identical                                | Identical                                 | Identical                    | Identical | Identical    | [Rmd](src/R/challenger.Rmd), [pdf](src/R/challenger_debian_alegrand.pdf)                                                                                                                                                                                                                                                                                     | A. Legrand  |
| Python   |            3.6.4 | statsmodels 0.9.0 numpy 1.13.3 pandas 0.22.0 matplotlib 2.2.2 | Jupyter | Linux Ubuntu 4.4.0-116-generic | Identical                                | Identical                                 | Identical                    | Identical | Similar      | [ipynb](src/Python3/challenger.ipynb), [pdf](src/Python3/challenger_ubuntuMOOC_alegrand.pdf)                                                                                                                                                                                                                                                                 | A. Legrand  |
| R        |            3.5.1 | ggplot2 3.0.0                                                 | RSrudio | Windows >= 8 x64 (build 9200)  | Identical                                | Identical                                 | Identical                    | Identical | Similar      | [Rmd](https://app-learninglab.inria.fr/moocrr/gitlab/8517fa92e97b3a318e653caefbfde6b5/mooc-rr/blob/master/module4/MOOC_exercice_module4.Rmd), [Pdf](https://app-learninglab.inria.fr/moocrr/gitlab/8517fa92e97b3a318e653caefbfde6b5/mooc-rr/blob/master/module4/MOOC_exercice_module4.pdf)                                                                   | M. Saubin   |
| Python   |            3.6.4 | statsmodels 0.9.0 numpy 1.15.2 pandas 0.22.0 matplotlib 2.2.3 | Jupyter | Linux Ubuntu 4.4.0-164-generic | Identical                                | Identical                                 | Identical                    | Identical | Similar      | [ipynb](module4/challenger_Python_ipynb.ipynb), [pdf](module4/challenger_Python_ipynb.pdf)                                                                                                                                                                                                                                                                   |2992438755465b7fe3afd7856bde0599|
